import { default as React } from 'react';

/**
 * Paginated content component with custom page handling.
 */
export declare function Paginate({ page, onChange, count, children }: React.PropsWithChildren<{
    /**
     * The current page.
     */
    page: number;
    /**
     * Called when a new page is selected.
     * @param newPage The newly selected page.
     */
    onChange: (newPage: number) => void;
    /**
     * Pages count.
     */
    count: number;
}>): React.JSX.Element;
/**
 * Paginated content component.
 */
export declare function AutoPaginate({ count, children }: {
    /**
     * Pages count.
     */
    count: number;
    /**
     * Show the given page.
     * @param page The page to show.
     */
    children: (page: number) => React.ReactElement;
}): React.JSX.Element;
/**
 * Asynchronous paginated content component.
 */
export declare function AsyncPaginate<T>({ count, getData, children }: {
    /**
     * Get pages count.
     */
    count: () => Promise<number>;
    /**
     * Get data for the given page.
     * @param page The page for which to get data.
     */
    getData: (page: number) => Promise<T>;
    /**
     * Show the current page with its retrieved data.
     * @param data Data of the page to show.
     * @param page The page to show.
     */
    children: (data: T, page: number) => React.ReactElement;
}): React.JSX.Element;
/**
 * An async page to render.
 */
export declare function AsyncPage<T>({ page, getData, render }: {
    /**
     * The page number to show.
     */
    page: number;
    /**
     * Get data for the given page.
     * @param page The page for which to get data.
     */
    getData: (page: number) => Promise<T>;
    /**
     * Render the page with its retrieved data.
     * @param data Data of the page to show.
     * @param page The page to show.
     */
    render: (data: T, page: number) => React.ReactElement;
}): React.JSX.Element;
